probnum.randprocs
=================

Random Processes.

Random processes generalize functions by encoding uncertainty over function
values in their covariance function. They can be used to model (deterministic)
functions which are not fully known or to define functions with stochastic output.

.. automodapi:: probnum.randprocs
    :no-heading:
    :no-main-docstr:
